[devel] Imported from libpng-1.5.1beta09.tar
diff --git a/LICENSE b/LICENSE
index 3bc056f..ad084b7 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.5.1beta09, January 23, 2011, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.1beta09, January 24, 2011, are
 Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-January 23, 2011
+January 24, 2011
diff --git a/README b/README
index 6e3a957..ceeda17 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.1beta09 - January 23, 2011 (shared library 15.0)
+README for libpng version 1.5.1beta09 - January 24, 2011 (shared library 15.0)
 See the note about version numbers near the top of png.h
 
 See INSTALL for instructions on how to install libpng.
diff --git a/libpng-manual.txt b/libpng-manual.txt
index 9624c9c..61541ff 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
 libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.5.1beta09 - January 23, 2011
+ libpng version 1.5.1beta09 - January 24, 2011
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.1beta09 - January 23, 2011
+ libpng versions 0.97, January 1998, through 1.5.1beta09 - January 24, 2011
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
 
@@ -1341,7 +1341,7 @@
 
     Y = 0.212671 * R + 0.715160 * G + 0.072169 * B
 
-Libpng approximates this integers scaled by 32768:
+Libpng approximates this with integers scaled by 32768:
 
     Y = (6968 * R + 23434 * G + 2366 * B)/32768
 
@@ -4073,7 +4073,7 @@
 
 XIV. Y2K Compliance in libpng
 
-January 23, 2011
+January 24, 2011
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
diff --git a/libpng.3 b/libpng.3
index aec0817..01c8c83 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,4 +1,4 @@
-.TH LIBPNG 3 "January 23, 2011"
+.TH LIBPNG 3 "January 24, 2011"
 .SH NAME
 libpng \- Portable Network Graphics (PNG) Reference Library 1.5.1beta09
 .SH SYNOPSIS
@@ -919,7 +919,7 @@
 .SH LIBPNG.TXT
 libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.5.1beta09 - January 23, 2011
+ libpng version 1.5.1beta09 - January 24, 2011
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -930,7 +930,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.1beta09 - January 23, 2011
+ libpng versions 0.97, January 1998, through 1.5.1beta09 - January 24, 2011
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
 
@@ -2260,16 +2260,12 @@
 
     Y = 0.212671 * R + 0.715160 * G + 0.072169 * B
 
-Libpng approximates this with
+Libpng approximates this with integers scaled by 32768:
 
-    Y = 0.21268 * R    + 0.7151 * G    + 0.07217 * B
-
-which can be expressed with integers as
-
-    Y = (6969 * R + 23434 * G + 2365 * B)/32768
+    Y = (6968 * R + 23434 * G + 2366 * B)/32768
 
 The calculation is done in a linear colorspace, if the image gamma
-is known.
+can be determined.
 
 If you have a grayscale and you are using png_set_expand_depth(),
 png_set_expand(), or png_set_gray_to_rgb to change to truecolor or to
@@ -4996,7 +4992,7 @@
 
 .SH XIV. Y2K Compliance in libpng
 
-January 23, 2011
+January 24, 2011
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
@@ -5242,7 +5238,7 @@
 
 Thanks to Frank J. T. Wojcik for helping with the documentation.
 
-Libpng version 1.5.1beta09 - January 23, 2011:
+Libpng version 1.5.1beta09 - January 24, 2011:
 Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
 Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
 
@@ -5265,7 +5261,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.5.1beta09, January 23, 2011, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.1beta09, January 24, 2011, are
 Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -5364,7 +5360,7 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-January 23, 2011
+January 24, 2011
 
 .\" end of man page
 
diff --git a/libpngpf.3 b/libpngpf.3
index 8bcfdae..fe07c6b 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "January 23, 2011"
+.TH LIBPNGPF 3 "January 24, 2011"
 .SH NAME
 libpng \- Portable Network Graphics (PNG) Reference Library 1.5.1beta09
 (private functions)
diff --git a/png.5 b/png.5
index 847d2d9..ce7988b 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "January 23, 2011"
+.TH PNG 5 "January 24, 2011"
 .SH NAME
 png \- Portable Network Graphics (PNG) format
 .SH DESCRIPTION
diff --git a/png.c b/png.c
index fffbfb4..b358c2b 100644
--- a/png.c
+++ b/png.c
@@ -555,13 +555,13 @@
 #else
 #  ifdef __STDC__
    return PNG_STRING_NEWLINE \
-     "libpng version 1.5.1beta09 - January 23, 2011" PNG_STRING_NEWLINE \
+     "libpng version 1.5.1beta09 - January 24, 2011" PNG_STRING_NEWLINE \
      "Copyright (c) 1998-2011 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
      "Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
      "Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
      PNG_STRING_NEWLINE;
 #  else
-      return "libpng version 1.5.1beta09 - January 23, 2011\
+      return "libpng version 1.5.1beta09 - January 24, 2011\
       Copyright (c) 1998-2011 Glenn Randers-Pehrson\
       Copyright (c) 1996-1997 Andreas Dilger\
       Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index b0f4472..0be21d8 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
 
 VisualStudio instructions
 
-libpng version 1.5.1beta09 - January 23, 2011
+libpng version 1.5.1beta09 - January 24, 2011
 
 Copyright (c) 1998-2010 Glenn Randers-Pehrson
 
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 83ce09b..993eda4 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
 <!--
  * zlib.props - location of zlib source
  *
- * libpng version 1.5.1beta09 - January 23, 2011
+ * libpng version 1.5.1beta09 - January 24, 2011
  *
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  *
diff --git a/scripts/README.txt b/scripts/README.txt
index 89ed154..5eb738b 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,5 +1,5 @@
 
-Makefiles for  libpng version 1.5.1beta09 - January 23, 2011
+Makefiles for  libpng version 1.5.1beta09 - January 24, 2011
 
 pnglibconf.h.prebuilt       =>  Stores configuration settings
  makefile.linux    =>  Linux/ELF makefile
diff --git a/png.h b/png.h
index a32d6ea..2d9d1eb 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.5.1beta09 - January 23, 2011
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
  * Authors and maintainers:
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *   libpng versions 0.97, January 1998, through 1.5.1beta09 - January 23, 2011: Glenn
  *   See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -176,7 +176,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.5.1beta09, January 23, 2011, are
  * Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -288,7 +288,7 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    January 23, 2011
+ *    January 24, 2011
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
@@ -352,7 +352,7 @@
 /* Version information for png.h - this should match the version in png.c */
 #define PNG_LIBPNG_VER_STRING "1.5.1beta09"
 #define PNG_HEADER_VERSION_STRING \
-     " libpng version 1.5.1beta09 - January 23, 2011\n"
+     " libpng version 1.5.1beta09 - January 24, 2011\n"
 
 #define PNG_LIBPNG_VER_SONUM   15
 #define PNG_LIBPNG_VER_DLLNUM  15
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.5.1beta09 - January 23, 2011
+ * libpng version 1.5.1beta09 - January 24, 2011
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *   libpng versions 0.97, January 1998, through 1.5.1beta09 - January 23, 2011: Glenn
+ *   libpng versions 0.97, January 1998, through 1.5.1beta09 - January 24, 2011: Glenn
  *   See also "Contributing Authors", below.
  *
@@ -176,7 +176,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.5.1beta09, January 23, 2011, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.1beta09, January 24, 2011, are
  * Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5